****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_createencmasterlist.sas  
*
* Created (mm/dd/yyyy): 02/01/2018
* Last modified: 
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*	This program will create the numerator dataset based on the POV1 and POV3 datasets
*
*  Program inputs:                                                                                   
*	-POV1 and POV3
* 
*  Program outputs:                                                                                                                                       
* 	-Dataset with valid numerator observations (_EncMasterList)
* 
* PARAMETERS:
*
*  Programming Notes:                                                                                
*                                                                           
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials	   Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*
***************************************************************************************************;

%macro ms_createencmasterlist();	

%put =====> MACRO CALLED: ms_createencmasterlist v1.0;

	data _EncMasterList;
		format enc_start enc_end date9.;
        merge _POV1(in=pov1 )
              _POV3(in=pov3 keep=patid encounterID);
        by Patid encounterID;		
        
        if pov1;
		if pov3 then EXCL = 0; else EXCL = 1;

        *Encounter start must overlap greater monitoring period;
        if &startfollowup. <= enc_start <= &enddate.;
          
        keep PatID encounterID enc_start enc_end discharge_disposition enctype facility_code birth_date age agegroup 
			 sex race hispanic excl;
	run;

%put NOTE: ********END OF MACRO: ms_createencmasterlist v1.0********;

%mend ms_createencmasterlist;
