****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_rxsummarytable.sas  
*
* Created (mm/dd/yyyy): 03/01/2018
* Last modified: 
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*   This macro will create the output table to summarize RxRoute, RxDose, and RxUOM
*	for index defining NDCs                              
*   
*  Program inputs:    
*	-_EncMasterList
*	-_ITInpatDrugs
*                                     
*  Program outputs:  
*	-MSOC.&RUNID._ipharm_summary.sas7bdat
*                                                                                                  
*  PARAMETERS:                                                                       
*            
*  Programming Notes:                                                                                
*                                                                           
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*
***************************************************************************************************;

%macro ms_rxsummarytable();

%put =====> MACRO CALLED: ms_rxsummarytable v1.0;

	*List of encounters to include in table;
	data _Enc;
		set _EncMasterList;
		where EXCL = 0;
		keep encounterID;
	run;

	*Extract all NDCs from _ITInpatDrugs for INDEX='DEF' and occurs during valid encounter;
	proc sql noprint;
		create table _ipharm as
		select pharm.patid,
			   pharm.encounterID,
			   case 
				when pharm.codetype = '09' then  substr(pharm.ndc, 1,9) 
			   	else pharm.ndc
			   end as code,
			   substr(pharm.ndc, 1,9) as code9,
			   pharm.rxroute,
			   pharm.rxdose,
			   pharm.rxuom,
			   pharm.codetype,
			   1 as dispensing
		from _itinpatdrugs(where=(index='DEF')) as pharm,
		_enc as enc
		where pharm.encounterID = _enc.encounterID
		order by code, rxroute, rxdose, rxuom;
	quit;

	*Summarize;
	proc means data=_ipharm nway noprint missing;
        var dispensing;
        class code RxRoute RxDose RxUOM;
        output out=_numdisp(drop=_:) sum(dispensing)=Count;         
    run;

	*square NDCs;
	proc sort data=_ITGroupParamInPatNDC(where=(index='DEF')) nodupkey out=_squaredNDCs(keep=code);
		by code;
	run;

	data _ipharm_summary(rename=code=ndc); 
		merge _numdisp
			  _squaredNDCs;
		by code;
		if missing(count) then count = 0;
		format group $30.;
		group = "&itgroup.";
	run;

	*Output;
	%if %eval(&group.=1) %then %do;
		data msoc.&runid._ipharm_summary; 
			retain group ndc rxroute rxdose rxuom count;
			set _ipharm_summary;
			keep group ndc rxroute rxdose rxuom count;
		run;
	%end;
	%else %do;
		data msoc.&runid._ipharm_summary; 
			set  msoc.&runid._ipharm_summary 
				_ipharm_summary(keep=group ndc rxroute rxdose rxuom count);
		run;
	%end;

%put NOTE: ******** END OF MACRO: ms_rxsummarytable  v1.0 ********;

%mend ms_rxsummarytable;
