/***************************************************************************************************
*                                           SENTINEL PROGRAM
****************************************************************************************************
* NAME:  /*QF TEAM: add name of program with .sas extension*/
*
* PURPOSE: /*QF TEAM: add language from the workplan*/
*
* MAJOR STEPS: See Routine Querying System documentation and request workplan
*
* KEY DEPENDENCIES/CONSTRAINTS/CAVEATS: /*QF TEAM: use this space to add details of type of data returned and other details*/
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
* HISTORY:
*  Create date (mm/dd/yy): 02/01/2018
*  Last modified date (mm/dd/yy): 
*  Version: 1.0
*  QRPE Version: 1.0.1
*
*  CHANGE LOG: 
*
*   Version   Date       Comment (reference external documentation when available)
*   -------   --------   -------------------------------------------------------------------------
*
**************************************************************************************************/

/* System options */
options nosymbolgen nomlogic ;
options ls=100 nocenter ;

/*-------------------------------------------------------------------------------------------------
*                                        DEFINITIONS
*--------------------------------------------------------------------------------------------------
* MSCC     ... Sentinel Common-Components File 
*              Specific to each Data Partner/Data Site, the Common-Components defines key
*                 - macro variables (e.g. Data Partner ID, Min and Max Dates, SCDM table names)   
*                 - libname assignments (e.g. libref INDATA is assigned to production SCDM tables) 
*              NOTE: This parameter needs to be set by programmer at the Data Partner/Data Site
*
* MSReqID  ... Sentinel Project Request-Id
*              NOTE: This parameter needs to be set by the programmer preparing the Request-ID
*                    in coordination with the Sentinel Operations Center (SOC)
*
* The following paths for the current request are automatically derived 
*    DPLOCAL  ... path for data created that remains local (i.e behind the DP firewall)
*    MSOC     ... path for data created to share with MS Operations Center
*    INFOLDER ... path for program inputs (e.g.lookup data, external macros)
*    SASPROGRAMS ... path for all SAS programs that are part of the data request
*-------------------------------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* NOTE: Data Partner/Data Site programmer defines parameters in this section */
/*----------------------------------------------------------------------------*/

/* Define Common Components Include File */
/* Example: //sentinel/common-components/ms_common_components.sas */
%let MSCC =B:\mscdm\v6.0\HCA\etl01\sample_2m\common_components\ms_common_components.sas ;

/* Edit this parameter to identify the list of patients to exclude (if applicable).
   Dataset should contain one variable, patid, and list all patids that should be
   excluded. Must include libname (e.g., indata.PtsToExclude).
 */
%let PTSTOEXCLUDE=;

**************************************************************************************************
*******                                  END OF USER INPUT                                  ******
*******                             DO NOT EDIT BELOW THIS LINE                             ******
*******                        (Consult with SOC or MS team leader                          ******
*******                           if you feel edits are required)                           ******
**************************************************************************************************;

/* Include Common Components */
%inc "&MSCC" /source2 ;

/*---------------------------------------------------------------------*/
/* NOTE: Programmer preparing Request-Id defines the                   */
/*       parameter MSReqID in coordination with the SOC                */
/*---------------------------------------------------------------------*/

/*-------------------------------------------------------------------------------------------------
* Specific requests are made up a project-id, workplan-type, workplan-id, unique-dpid, version-id           
*--------------------------------------------------------------------------------------------------
*
*        If this is your request   . . . . .  then set parameter values as follows 
*   ---------------------------------     -------------------------------------------------------
*   [Task Order 7 - NME Dabigatran]       %let MSProjID = to07_nme_dabi ;  
*   [WorkPlan Type]                       %let MSWPType = ahr; 
*   [Workplan # 5]                        %let MSWPID = wp005 ; 
*   [Unique DP id]                        %let MSDPID = nsdp ;     
*   [Beta 3]                              %let MSVerID = b03 ;         
*   [use underscores as delimiter]        %let dlm = _ ;                
*
*   The example values above would produce a Request-Id equal to to07_nme_dabi_ahr_wp005_nsdp_b03
*
*--------------------------------------------------------------------------------------------------*/

* Specify project-id, workplan-type, workplan-id, workplan-type, unique-dpid, version-id *;
%let MSProjID = edit-project-id; 
%let MSWPType = edit-workplantype-id;      
%let MSWPID   = edit-workplan-id;        
%let MSDPID   = edit-unique DP-id;              /* Note: set value to nsdp for non-specific DP type requests */
%let MSVerID  = edit-version-id;        
%let dlm = _ ; 

* Request-Id *;
%let MSReqID = &MSProjID.&dlm.&MSWPType.&dlm.&MSWPID.&dlm.&MSDPID.&dlm.&MSVerID.;

* Delete macro variable used as delimiter as we no longer need it *;
%symdel dlm ; 


*-------------------------------------------------------------------------------------------------
* 0- Setup Environment
*-------------------------------------------------------------------------------------------------;

/*---------------------------------------------------------------------*/
/* NOTE: This is standard SOC environment setup code -- Do Not Edit    */
/*---------------------------------------------------------------------*/

/* System options */
options obs=MAX ;
options msglevel=i ;
options mprint mprintnest ;
options errorcheck=strict errors=0 ;
options merror serror ;
options dkricond=error dkrocond=error mergenoby=warn;
options dsoptions=nonote2err noquotelenmax ;
options reuse=no ;
options fullstimer ;
options validvarname = v7;

/*------------------------------------------------------------------------------------------------
* NOTES:
*   For reasons of compatibility and standardization, paths must meet the following criteria:
*     1- Starting with the request subdirectory, all subdirectory names must be specified in
*        lower case (for UNIX compatibility)
*     2- Slashes must be forward-leaning slashes '/' (for UNIX compatibility)
*     3- Paths must end with a final forward-leaning slash '/' (extra slashes are fine)
*------------------------------------------------------------------------------------------------*/

/* Request-Id parameter value must be lower case */
%let MSReqID = %lowcase(&MSReqID) ;

/* Define Request Specific Subdirectories */
%let DPLOCAL = &_root_dplocal.&MSReqID./dplocal/ ; 
%let MSOC = &_root_msoc.&MSReqID./msoc/ ;            
%let INFOLDER = &_root_inputfiles.&MSReqID./inputfiles/ ;  
%let SASPROGRAMS = &_root_sasprograms.&MSReqID./sasprograms/ ;

/* Clean up paths (e.g. convert slashes and add slashes when necessary) and validate that paths exist */
%let DPLOCAL = %ms_clean_path(&DPLOCAL) ;
%let MSOC = %ms_clean_path(&MSOC) ;
%let INFOLDER = %ms_clean_path(&INFOLDER) ;
%let SASPROGRAMS = %ms_clean_path(&SASPROGRAMS) ;

/* Assign libnames */
/* %ms_lib(libref-name, path-name, options=%str(options-name=options-value)) */
%ms_lib(dplocal, &DPLOCAL) 
%ms_lib(msoc, &MSOC) 
%ms_lib(infolder, &INFOLDER, options=%str(access=readonly));


/********** FOLDER CONTAINING INPUT SAS MACROS USED BY THE MAIN PROGRAM *************************/;
/*Macro Files Location*/          %let sasmacr=&INFOLDER./macros/;			

**************************************************************************************************
*******                                  BEGIN PROGRAM                                     *******
**************************************************************************************************;

/*---------------------------------------------------------------------*/
/* NOTE: Programmer preparing request includes/writes                  */
/*       the rest of the program below                                 */
/*---------------------------------------------------------------------*/

*--------------------------------------------------------------------------------------------------
* 1- 
*--------------------------------------------------------------------------------------------------;

**Include macro and program files ** ;  
%include "&sasmacr.ms_agestrat.sas";
%include "&sasmacr.ms_caresettingprincipal.sas";
%include "&sasmacr.ms_createencmasterlist.sas";
%include "&sasmacr.ms_delpatients.sas";
%include "&sasmacr.ms_extractinpatientdrugs.sas";
%include "&sasmacr.ms_extractmeds.sas";
%include "&sasmacr.ms_finalize_encmasterlist.sas";
%include "&sasmacr.ms_freezedata.sas";
%include "&sasmacr.ms_macros.sas";
%include "&sasmacr.ms_padmit.sas";
%include "&sasmacr.ms_periodsoverlap.sas";
%include "&sasmacr.ms_processwildcards.sas";
%include "&sasmacr.ms_qrpe_attrition.sas";
%include "&sasmacr.ms_qrpe_createpov1.sas";
%include "&sasmacr.ms_qrpe_createpov3.sas";
%include "&sasmacr.ms_qrpe_createpov5.sas";
%include "&sasmacr.ms_qrpe_initmacrovariables.sas";
%include "&sasmacr.ms_qrpe_loopmeds.sas";
%include "&sasmacr.ms_qrpe_processinputfiles.sas";
%include "&sasmacr.ms_qrpe_setloopmacrovars.sas";
%include "&sasmacr.ms_qrpecov.sas";
%include "&sasmacr.ms_qrpedenom.sas";
%include "&sasmacr.ms_qrpenum.sas";
%include "&sasmacr.ms_qrpetables.sas";
%include "&sasmacr.ms_restricttoencounter.sas";
%include "&sasmacr.ms_rxsummarytable.sas";
%include "&sasmacr.ms_time.sas";

**Include run_programs;
%include "&infolder.run_programs.sas";
